@@ -3,11 +3,9 @@ package Data::Mining::Apriori;
 use 5.010001;
 use strict;
 use warnings;
-use threads;
-use threads::shared;
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 my $self;
 
@@ -15,20 +13,6 @@ $" = ', ';
 $| = 1;
 $SIG{'INT'} = \&stop;
 
-my $spin : shared = 1;
-my $showSpin : shared = 0;
-
-async{
-	while($spin){
-		do{
-			select undef, undef, undef, 0.1;
-			printf "$_\b" if $showSpin;
-		}
-		for qw(/ - \ |);
-	}
-}
-->detach;
-
 sub new{
 	my $type = shift;
 	my $class = ref($type)||$type;
@@ -99,13 +83,9 @@ sub association_rules_itemset_size{
 	}
 	my @newItemsetCandidateSizeOne = ();
 	if($self->{messages}){
-		$showSpin=1;
 		print "\n\nItemset size ", $self->{itemsetSize}, ", ", scalar(@itemsetCandidateSizeOne), " items ";
 		print "\nProcessing... ";
 	}
-	else{
-		$spin=0;
-	}
 	for(my$itemsetSize=2;$itemsetSize<=$itemsetSizeLimit;$itemsetSize++){
 		my $code=<<'CODE';
 my @itemsetCandidate=();
@@ -159,17 +139,11 @@ for(my$subsetSize=0;$subsetSize<$#itemsetCandidate;$subsetSize++){
 			@{$self->{associationRules}{$self->{rule}}{"R$self->{rule}"}{rule}} = ("{ @subsetLeft } => { @subsetRight }", $support, $confidence);
 			@{$self->{associationRules}{$self->{rule}}{"R$self->{rule}"}{items}} = ();
 			push @{$self->{associationRules}{$self->{rule}}{"R$self->{rule}"}{items}},@subsetLeft;
-			foreach my$item(@subsetLeft){
-				if(!($item ~~ @newItemsetCandidateSizeOne)){
-					push @newItemsetCandidateSizeOne,$item;
-				}
-			}
+			my@items=grep!($_~~@newItemsetCandidateSizeOne),@subsetLeft;
+			push @newItemsetCandidateSizeOne,@items;
 			push @{$self->{associationRules}{$self->{rule}}{"R$self->{rule}"}{items}},@subsetRight;			
-			foreach my$item(@subsetRight){
-				if(!($item ~~ @newItemsetCandidateSizeOne)){
-					push @newItemsetCandidateSizeOne,$item;
-				}
-			}
+			@items=grep!($_~~@newItemsetCandidateSizeOne),@subsetRight;
+			push @newItemsetCandidateSizeOne,@items;			
 		}
 	}
 }
@@ -207,7 +181,6 @@ sub stop{
 	if($self->{messages}){
 		print "\nStopping... ";
 		$self->output if $self->{associationRules};
-		$showSpin=0;		
 		print "\nExit? (Y/N): ";
 		my $exit = <STDIN>;
 		chomp($exit);
@@ -215,7 +188,6 @@ sub stop{
 			exit;
 		}
 		else{
-			$showSpin=1;
 			print "\nProcessing... ";
 		}
 	}
@@ -321,7 +293,7 @@ sub excel{
 		$worksheet->write("A$line","$item $self->{itemsKeyDescription}{$item}");
 		$line++;
 	}
-	$workbook->close();
+	$workbook->close;
 }
 
 return 1;
@@ -356,7 +328,7 @@ Data::Mining::Apriori - Perl extension for implement the apriori algorithm of da
 
 	$apriori->{minConfidence}=1.55; # The minimum confidence
 
-	$apriori->{output}=1; # The output type (1 - Export to file; 2 - Export to excel.)(optional)
+	$apriori->{output}=1; # The output type (1 - Export to file; 2 - Export to excel)(optional)
 
 	$apriori->{messages}=1; # A value boolean to display the messages(optional)
 
@@ -518,9 +490,13 @@ The output type (optional):
 
 =over 4
 
-=item 1 - Export to file;
+=item 1
 
-=item 2 - Export to excel.
+- Text file;
+
+=item 2
+
+- Excel file.
 
 =back
 
